@@ -7,17 +7,23 @@
 @ Gitee : https://gitee.com/ZeroSeeker
 """
 import showlog
+import random
 import oss2
 import envx
+import uuid
 """
 SDK文档：https://help.aliyun.com/document_detail/32026.html
 """
 env_file_name_default = 'aliyun.oss.env'
+uuid_node = random.randint(100000000, 999999999)  # 避免泄密设备信息
 
 
 def make_con_info(
         env_file_name: str = env_file_name_default
 ):
+    """
+    生成连接信息
+    """
     inner_env = envx.read(file_name=env_file_name)
     if inner_env is None or len(inner_env) == 0:
         showlog.warning('[%s]文件不存在或文件填写错误！' % env_file_name)
@@ -180,17 +186,17 @@ class Basics:
 
 
 def upload_file(
-        oss_filename,
         local_filename,
+        oss_filename=None,
         custom_host=None,
         env_file_name: str = env_file_name_default,
         con_info: dict = None,
         headers: dict = None
 ):
     """
-    上传文件（从本地读取）
-    :param oss_filename: 上传oss后的文件名
+    上传文件（从本地读取），如果需要上传到某文件夹，可以将oss_filename设置为path/filename
     :param local_filename: 本地待上传的文件名
+    :param oss_filename: 上传oss后的文件名
     :param custom_host: 自定义域名
     :param env_file_name: 环境文件名
     :param con_info: 环境
@@ -201,6 +207,8 @@ def upload_file(
         con_info = make_con_info(env_file_name=env_file_name)
     else:
         pass
+    if not oss_filename:
+        oss_filename = uuid.uuid1(node=uuid_node)
     # ---------------- 固定设置 ----------------
     basic = Basics(con_info=con_info)
     res = basic.upload_file(
@@ -222,23 +230,24 @@ def upload_file(
         'base_url': base_url,
         'custom_host': custom_host,
         'custom_http_url': custom_http_url,
-        'custom_https_url': custom_https_url
+        'custom_https_url': custom_https_url,
+        'oss_filename': oss_filename
     }
     return response
 
 
 def upload_content(
-        oss_filename,
         data,
+        oss_filename=None,
         custom_host=None,
         env_file_name: str = env_file_name_default,
         con_info: dict = None,
         headers: dict = None
 ):
     """
-    上传内容（二进制对象）
-    :param oss_filename: 上传oss后的文件名
+    上传内容（二进制对象），如果需要上传到某文件夹，可以将oss_filename设置为path/filename
     :param data: 待上传对象，二进制内容
+    :param oss_filename: 上传oss后的文件名
     :param custom_host: 自定义域名
     :param env_file_name: 环境文件名
     :param con_info: 环境
@@ -249,6 +258,8 @@ def upload_content(
         con_info = make_con_info(env_file_name=env_file_name)
     else:
         pass
+    if not oss_filename:
+        oss_filename = uuid.uuid1(node=uuid_node)
     # ---------------- 固定设置 ----------------
     basic = Basics(con_info=con_info)
     res = basic.upload_object(
@@ -270,6 +281,7 @@ def upload_content(
         'base_url': base_url,
         'custom_host': custom_host,
         'custom_http_url': custom_http_url,
-        'custom_https_url': custom_https_url
+        'custom_https_url': custom_https_url,
+        'oss_filename': oss_filename
     }
     return response
